summaryrefslogtreecommitdiff
path: root/scripts/mysqld_multi.sh
diff options
context:
space:
mode:
authordf@kahlann.erinye.com <>2006-12-07 15:02:32 +0100
committerdf@kahlann.erinye.com <>2006-12-07 15:02:32 +0100
commit77965c013cc99c153121cd33e74b18eeae29168a (patch)
tree9929a44698f605d5a19f1cb2617b2968df1091e3 /scripts/mysqld_multi.sh
parent6541302bb2841af6f24070ec0e8371ac064834c6 (diff)
downloadmariadb-git-77965c013cc99c153121cd33e74b18eeae29168a.tar.gz
BUG#24780 use --sysconfdir in scripts
Diffstat (limited to 'scripts/mysqld_multi.sh')
-rw-r--r--scripts/mysqld_multi.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/scripts/mysqld_multi.sh b/scripts/mysqld_multi.sh
index 4a6f380494f..ce778c03206 100644
--- a/scripts/mysqld_multi.sh
+++ b/scripts/mysqld_multi.sh
@@ -429,9 +429,9 @@ sub find_groups
}
else
{
- if (-f "/etc/my.cnf" && -r "/etc/my.cnf")
+ if (-f "@sysconfdir@/my.cnf" && -r "@sysconfdir@/my.cnf")
{
- open(MY_CNF, "</etc/my.cnf") && (@tmp=<MY_CNF>) && close(MY_CNF);
+ open(MY_CNF, "<@sysconfdir@/my.cnf") && (@tmp=<MY_CNF>) && close(MY_CNF);
}
for ($i = 0; ($line = shift @tmp); $i++)
{
@@ -658,7 +658,7 @@ sub example
# (as per Linux/Unix standard). You may even replace the
# /etc/init.d/mysql.server script with it.
#
# Before using, you must create a my.cnf file either in /etc/my.cnf
# or /root/.my.cnf and add the [mysqld_multi] and [mysqld#] groups.
#
# The script can be found from support-files/mysqld_multi.server.sh
@@ -658,7 +658,7 @@ sub example
# /etc/init.d/mysql.server script with it.
#
-# Before using, you must create a my.cnf file either in /etc/my.cnf
+# Before using, you must create a my.cnf file either in @sysconfdir@/my.cnf
# or /root/.my.cnf and add the [mysqld_multi] and [mysqld#] groups.
#